Completed Features
==================

Here are the features we've completed (most recent first):

- Fix error in initiating payment
- Better handling of payment errors (reject jobs the system can't afford)
- Site Design
- Improved persistence (S3 storage or similar)
- Same Job Detection
- Typist Rejection (for jobs that are too complex)
- Terms and Conditions
- Privacy Policy
- Auto-refresh Status Page
- Improved Sample HIT support
- Thread Safety
- Basic Aesthetics
- Payment System
- Basic functional workflow
- Job persistence
- Native PDF handling (PyPDF)
- Run as daemon
- document upload
- document processing
